@@ -23,87 +23,84 @@
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="14"/>
-        <location filename="mainwindow.cpp" line="142"/>
-        <location filename="mainwindow.cpp" line="271"/>
+        <location filename="mainwindow.cpp" line="147"/>
+        <location filename="mainwindow.cpp" line="298"/>
         <source>QCPUFreq</source>
         <translation>QCPUFreq</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="34"/>
+        <location filename="mainwindow.ui" line="40"/>
         <source>Minimum CPU speed:</source>
         <translation>Min. CPU Frequenz:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="41"/>
-        <location filename="mainwindow.ui" line="55"/>
-        <location filename="mainwindow.ui" line="69"/>
-        <location filename="mainwindow.ui" line="83"/>
-        <location filename="mainwindow.cpp" line="157"/>
+        <location filename="mainwindow.ui" line="47"/>
+        <location filename="mainwindow.ui" line="67"/>
+        <location filename="mainwindow.ui" line="87"/>
+        <location filename="mainwindow.ui" line="107"/>
+        <location filename="mainwindow.cpp" line="175"/>
+        <location filename="mainwindow.cpp" line="184"/>
         <source>Unknown</source>
         <translation>Unbekannt</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="48"/>
+        <location filename="mainwindow.ui" line="60"/>
         <source>Maximum CPU speed:</source>
         <translation>Max. CPU Frequenz:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="62"/>
-        <source>Current scaling governor:</source>
-        <translation>Aktueller Skalierer:</translation>
+        <location filename="mainwindow.ui" line="80"/>
+        <source>Scaling governor:</source>
+        <translation>Scaling Governor:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="76"/>
-        <source>Current CPU temperature:</source>
-        <translation>Aktuelle CPU Temperatur:</translation>
+        <location filename="mainwindow.ui" line="100"/>
+        <source>CPU temperature:</source>
+        <translation>CPU Temperatur:</translation>
     </message>
     <message utf8="true">
-        <location filename="mainwindow.ui" line="96"/>
+        <location filename="mainwindow.ui" line="126"/>
         <source>SmartReflex™:</source>
         <translation>SmartReflex™:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="109"/>
+        <location filename="mainwindow.ui" line="139"/>
         <source>Enable</source>
         <oldsource>Disabled</oldsource>
         <translation>Aktivieren</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="306"/>
+        <location filename="mainwindow.ui" line="336"/>
         <source>Set maximum CPU frequency:</source>
         <translation>Maximale CPU Frequenz einstellen:</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="334"/>
+        <location filename="mainwindow.ui" line="364"/>
         <source>File</source>
         <translation>Datei</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="343"/>
+        <location filename="mainwindow.ui" line="373"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="348"/>
+        <location filename="mainwindow.ui" line="378"/>
         <source>Help</source>
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="142"/>
+        <location filename="mainwindow.cpp" line="147"/>
         <source>There seems to be a problem with your sudo setup!</source>
         <translation>Es liegt offenbar ein Problem bei der sudo Einrichtung vor!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="271"/>
+        <location filename="mainwindow.cpp" line="298"/>
         <source>Could not get information from /sys!</source>
         <translation>Konnte Informationen aus /sys nicht lesen!</translation>
     </message>
     <message>
-        <source>Enabled</source>
-        <translation type="obsolete">Aktiviert</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="374"/>
+        <location filename="mainwindow.cpp" line="404"/>
         <source>SmartReflex support is known to be unstable on some devices and may cause random reboots.</source>
         <translation>SmartReflex kann auf einigen Geräten instabil sein und zu zufälligen Neustarts führen.</translation>
     </message>
