@@ -25,7 +25,7 @@ HelpWindow::HelpWindow(QWidget *parent) :
     QPalette palette;
     QBrush brush = palette.windowText();
     QColor color = brush.color();
-    ui->textBrowser->setStyleSheet( "background: transparent; color: " + color.name() + ";" );
+    ui->textBrowser->setStyleSheet( "QTextEdit {background: transparent; color: " + color.name() + ";}" );
 }
 
 
