@@ -29,7 +29,7 @@
 
 
 #define APPNAME "QCPUFreq"
-#define APPVERSION "0.3"
+#define APPVERSION "0.3.2"
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -105,6 +105,11 @@ void MainWindow::adjustFreq()
 {
     int newmax = getScalingFreq( ui->freq_adjust->sliderPosition() );
     QString max;
+
+    //maxfreq should not be smaller than minfreq, because we do not want to decrease minfreq
+    if (newmax < getMinFreq())
+	newmax = getMinFreq();
+
     max.setNum( newmax );
 
     callHelper( "set_maxfreq", max );
@@ -125,7 +130,7 @@ int MainWindow::callHelper(QString action, QString param)
     QStringList arguments;
 
     #if defined(Q_WS_MAEMO_5)
-	//On Maemo 5 the helper script resides in /opt/usr/bin, which us usually not in $PATH
+	//On Maemo 5 the helper script resides in /opt/usr/bin, which is usually not in $PATH
 	arguments.append( "/opt/usr/bin/QCPUFreq.helper" );
     #else
 	arguments.append( "QCPUFreq.helper" );
@@ -136,7 +141,7 @@ int MainWindow::callHelper(QString action, QString param)
 
     helperProcess->start( "sudo", arguments, QIODevice::NotOpen );
 
-    if ( showSudoError && !helperProcess->waitForFinished( 200 )) {
+    if ( showSudoError && !helperProcess->waitForFinished( 400 )) {
 	//do not show this error again
 	showSudoError = false;
 	QMessageBox::critical(this, tr("QCPUFreq"), tr("There seems to be a problem with your sudo setup!"));
@@ -152,7 +157,29 @@ int MainWindow::callHelper(QString action, QString param)
 QString MainWindow::getCPUTemp()
 {
 #if defined(Q_WS_MAEMO_5)
-    return readSysFile( "devices/platform/omap34xx_temp/temp1_input_raw" );
+    QFile file( "/sys/class/power_supply/bq27200-0/temp" );
+
+    //check if we can read a more accurate temperature (only for power kernel)
+    if (file.exists())
+	return QString( readSysFile( "class/power_supply/bq27200-0/temp" ) + " " + QString::fromUtf8("\302\260") + "C" );
+    else {
+	/*
+	    We actually only need to read the raw temperature, but it appears that by also reading temp1_input
+	    the raw temperature (temp1_input_raw) is being updated more frequently.
+	*/
+	readSysFile( "devices/platform/omap34xx_temp/temp1_input" );
+
+	//read the current system temperature
+	QString tstring = readSysFile( "devices/platform/omap34xx_temp/temp1_input_raw" );
+	if (tstring == "0")
+	    return tr( "Unknown" );
+
+	//convert it to an integer and calculate the approx. temperature from the raw value
+	int tint = tstring.toInt();
+	tint = ( 0.65 * tint );
+	tstring.setNum(tint);
+	return QString( tstring + " " + QString::fromUtf8("\302\260") + "C" );
+    }
 #endif
     return tr( "Unknown" );
 }
@@ -276,6 +303,9 @@ QString MainWindow::readSysFile(QString sys_file)
     QTextStream in( &file );
     QString txt = in.readLine();
 
+    //close the file
+    file.close();
+
     return txt;
 }
 
